ToDo before release v1.1.0
==========================

Add examples
------------
* Create examples directory
* Add example code snippets to illustrate typical usage of pys5p modules
* Add README
* [TBD] The example code will probably require Tropomi data sets, which are too
large to distribute with the code. How to solve this?

Test Driven Development
-----------------------
* Introduce TDD with Python using Python’s built-in unittest module
